function addFullScreenMessage(message, image, duration, delay, colour, font)
    local game_resolution = game.WindowResolution
    local draw_font = getObject(font) --Specified font comes as a tuple, convert it to object
    graphics.font = draw_font --Set font for graphics calculations
    local lines = graphics.performLinebreaks(message) --Depends on font max line width
    local line_number = #lines --Count resulting lines
    local line_height = graphics.fontLineHeight() --Find line height
    if image ~= nil then
        image = graphics.loadFromFile(image)
    end
    fullscreen_message_alpha = 0
    
    local cursor_already_hidden = not game.HideCursor
    if cursor_already_hidden then
        game.HideCursor = true --Hides cursor while fullscreen message in effect so that can't keep clicking on things
    else
        cursor_already_hidden = true
    end
    system.pauseCurrentActions() --Action part will wait until completion
    startTween('fullscreen_message_alpha', fullscreen_message_alpha, 1, delay, easeLinearInOut) --Do fade effect
    graphics.addDrawFunc('draw_meanwhile()', 1)
    
    setDelay(duration, function() --Print message only for specified duration
        startTween('fullscreen_message_alpha', fullscreen_message_alpha, 0, delay, easeLinearInOut)
        setDelay(delay, function()
            graphics.removeDrawFunc('draw_meanwhile()')
            system.resumeAllActions() --Resume from action pause
            if not cursor_already_hidden then
                game.HideCursor = false
            end
        end)
    end)

    function draw_meanwhile()
        graphics.font = draw_font --Set font for graphics print
        graphics.drawBox(0, 0, game_resolution.x, game_resolution.y, colour, fullscreen_message_alpha)
        if image ~= nil then
            graphics.drawSprite(image, fullscreen_message_alpha)
        end

        for i = 1, line_number do
            local line_width = graphics.fontDimension(lines[i]).x / 2
            local line_x = math.floor(game_resolution.x / 2 - line_width)
            local line_y = math.floor(game_resolution.y / 2 - line_height * line_number / 2 + line_height * (i - 1))
            graphics.drawFont(lines[i], line_x , line_y, fullscreen_message_alpha)
        end
    end
end

registerActionPart('FULLSCREEN_MESSAGE',function(activeAction, actionPart)
	addFullScreenMessage(actionPart:getTextStr(VActionPartLink), actionPart.Path, actionPart.Int, actionPart.AltInt, actionPart.AltInt2, actionPart.String)
	return false -- end of action
end)